@@ -29,6 +29,18 @@ impl MemoryFormatter {
     pub fn set_percentage(&mut self) {
         self.percentage = self.used as f64 / self.total as f64 * 100f64;
     }
+
+    pub fn get_used(&self) -> ByteSize {
+        ByteSize::kb(self.used)
+    }
+
+    pub fn get_total(&self) -> ByteSize {
+        ByteSize::kb(self.total)
+    }
+
+    pub fn get_percentage(&self) -> String {
+        format!("{:.1}%", self.percentage)
+    }
 }
 
 impl Iconize for MemoryFormatter {
@@ -41,10 +53,10 @@ impl fmt::Display for MemoryFormatter {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(
             f,
-            "{} / {} ({:.1}%)",
-            ByteSize::kb(self.used),
-            ByteSize::kb(self.total),
-            self.percentage
+            "{} / {} ({})",
+            self.get_used(),
+            self.get_total(),
+            self.get_percentage()
         )
     }
 }
